@@ -22,6 +22,7 @@
  *
  */
 #include "mainwindow.h"
+#include "kerfuffle/archive.h"
 #include "part/interface.h"
 
 #include <KPluginLoader>
@@ -76,7 +77,7 @@ MainWindow::~MainWindow()
 
 void MainWindow::dragEnterEvent(QDragEnterEvent * event)
 {
-    kDebug(1601) << event;
+    kDebug() << event;
 
     Interface *iface = qobject_cast<Interface*>(m_part);
     if (iface->isBusy()) return;
@@ -89,7 +90,7 @@ void MainWindow::dragEnterEvent(QDragEnterEvent * event)
 
 void MainWindow::dropEvent(QDropEvent * event)
 {
-    kDebug(1601) << event;
+    kDebug() << event;
 
     Interface *iface = qobject_cast<Interface*>(m_part);
     if (iface->isBusy()) return;
@@ -105,7 +106,7 @@ void MainWindow::dropEvent(QDropEvent * event)
 
 void MainWindow::dragMoveEvent(QDragMoveEvent * event)
 {
-    kDebug(1601) << event;
+    kDebug() << event;
 
     Interface *iface = qobject_cast<Interface*>(m_part);
     if (iface->isBusy()) return;
@@ -117,7 +118,7 @@ void MainWindow::dragMoveEvent(QDragMoveEvent * event)
 
 bool MainWindow::loadPart()
 {
-    KPluginFactory *factory = KPluginLoader("libarkpart").factory();
+    KPluginFactory *factory = KPluginLoader("arkpart").factory();
     if (factory) {
         m_part = static_cast<KParts::ReadWritePart*>(factory->create<KParts::ReadWritePart>(this));
     }
@@ -132,6 +133,7 @@ bool MainWindow::loadPart()
 
     connect(m_part, SIGNAL(busy()), this, SLOT(updateActions()));
     connect(m_part, SIGNAL(ready()), this, SLOT(updateActions()));
+    connect(m_part, SIGNAL(quit()), this, SLOT(quit()));
 
     return true;
 }
@@ -194,7 +196,7 @@ void MainWindow::openArchive()
     Interface *iface = qobject_cast<Interface*>(m_part);
     Q_ASSERT(iface);
     KUrl url = KFileDialog::getOpenUrl(KUrl("kfiledialog:///ArkOpenDir"),
-                                       iface->supportedMimeTypes().join(" "),
+                                       Kerfuffle::supportedMimeTypes().join(" "),
                                        this);
     openUrl(url);
 }
@@ -230,9 +232,9 @@ void MainWindow::newArchive()
 {
     Interface *iface = qobject_cast<Interface*>(m_part);
     Q_ASSERT(iface);
-    QStringList mimeTypes = iface->supportedWriteMimeTypes();
+    QStringList mimeTypes = Kerfuffle::supportedWriteMimeTypes();
 
-    kDebug(1601) << "Supported mimetypes are" << mimeTypes.join(" ");
+    kDebug() << "Supported mimetypes are" << mimeTypes.join(" ");
 
     QString saveFile = KFileDialog::getSaveFileName(KUrl("kfiledialog:///ArkNewDir"),
                        mimeTypes.join(" "));
