@@ -34,7 +34,7 @@
 
 namespace Kerfuffle
 {
-class KERFUFFLE_EXPORT ArchiveBase: public QObject, public Archive
+class KERFUFFLE_EXPORT ArchiveBase: public Archive
 {
     Q_OBJECT
 public:
@@ -53,8 +53,8 @@ public:
     virtual AddJob* addFiles(const QStringList & files, const CompressionOptions& options = CompressionOptions());
     virtual ExtractJob* copyFiles(const QList<QVariant> & files, const QString & destinationDir, ExtractionOptions options);
 
-    virtual bool isReadOnly();
-    virtual QString fileName();
+    virtual bool isReadOnly() const;
+    virtual QString fileName() const;
 
     virtual bool isSingleFolderArchive();
     virtual QString subfolderName();
@@ -70,8 +70,8 @@ private:
     void listIfNotListed();
     ReadOnlyArchiveInterface *m_iface;
     bool m_hasBeenListed;
-    bool m_isSingleFolderArchive;
     bool m_isPasswordProtected;
+    bool m_isSingleFolderArchive;
     QString m_subfolderName;
     qlonglong m_extractedFilesSize;
 
