@@ -89,9 +89,10 @@ public:
     const ArchiveEntry &entry() const {
         return m_entry;
     }
-    void setEntry(const ArchiveEntry & entry) {
+    void setEntry(const ArchiveEntry& entry) {
         m_entry = entry;
-        QStringList pieces = entry[ FileName ].toString().split('/', QString::SkipEmptyParts);
+
+        const QStringList pieces = entry[FileName].toString().split('/', QString::SkipEmptyParts);
         m_name = pieces.isEmpty() ? QString() : pieces.last();
     }
 
@@ -239,7 +240,7 @@ QVariant ArchiveModel::data(const QModelIndex &index, int role) const
                         return QVariant();
                     }
                 }
-            case Ratio:
+            case Ratio: // TODO: Use node->entry()[Ratio] when available
                 if (node->isDir() || node->entry().contains(Link)) {
                     return QVariant();
                 } else {
@@ -664,7 +665,7 @@ void ArchiveModel::slotEntryRemoved(const QString & path)
     }
 }
 
-void ArchiveModel::slotUserQuery(Query *query)
+void ArchiveModel::slotUserQuery(Kerfuffle::Query *query)
 {
     query->execute();
 }
@@ -818,7 +819,8 @@ KJob* ArchiveModel::setArchive(Kerfuffle::Archive *archive)
         connect(job, SIGNAL(result(KJob *)),
                 this, SLOT(slotLoadingFinished(KJob *)));
 
-        connect(job, SIGNAL(userQuery(Query*)), this, SLOT(slotUserQuery(Query*)));
+        connect(job, SIGNAL(userQuery(Kerfuffle::Query*)),
+                this, SLOT(slotUserQuery(Kerfuffle::Query*)));
 
         emit loadingStarted();
 
@@ -840,8 +842,8 @@ ExtractJob* ArchiveModel::extractFiles(const QList<QVariant>& files, const QStri
 {
     Q_ASSERT(m_archive);
     ExtractJob *newJob = m_archive->copyFiles(files, destinationDir, options);
-    connect(newJob, SIGNAL(userQuery(Query*)),
-            this, SLOT(slotUserQuery(Query*)));
+    connect(newJob, SIGNAL(userQuery(Kerfuffle::Query*)),
+            this, SLOT(slotUserQuery(Kerfuffle::Query*)));
     return newJob;
 }
 
@@ -853,8 +855,8 @@ AddJob* ArchiveModel::addFiles(const QStringList & filenames, const CompressionO
         AddJob *job = m_archive->addFiles(filenames, options);
         connect(job, SIGNAL(newEntry(const ArchiveEntry&)),
                 this, SLOT(slotNewEntry(const ArchiveEntry&)));
-        connect(job, SIGNAL(userQuery(Query*)),
-                this, SLOT(slotUserQuery(Query*)));
+        connect(job, SIGNAL(userQuery(Kerfuffle::Query*)),
+                this, SLOT(slotUserQuery(Kerfuffle::Query*)));
 
 
         return job;
@@ -873,8 +875,8 @@ DeleteJob* ArchiveModel::deleteFiles(const QList<QVariant> & files)
         connect(job, SIGNAL(finished(KJob*)),
                 this, SLOT(slotCleanupEmptyDirs()));
 
-        connect(job, SIGNAL(userQuery(Query*)),
-                this, SLOT(slotUserQuery(Query*)));
+        connect(job, SIGNAL(userQuery(Kerfuffle::Query*)),
+                this, SLOT(slotUserQuery(Kerfuffle::Query*)));
         return job;
     }
     return 0;
