@@ -23,11 +23,11 @@
 #ifndef KPIECETABLE_REMOVEPIECETABLECHANGE_H
 #define KPIECETABLE_REMOVEPIECETABLECHANGE_H
 
-
 // lib
 #include "abstractpiecetablechange.h"
 #include "piecelist.h"
 
+
 namespace KPieceTable
 {
 
@@ -38,24 +38,27 @@ namespace KPieceTable
 class RemovePieceTableChange : public AbstractPieceTableChange
 {
   public:
-    RemovePieceTableChange( const KHE::Section &removeSection, const PieceList &removedPieces );
+    RemovePieceTableChange( const AddressRange& removeRange, const PieceList& removedPieces );
     virtual ~RemovePieceTableChange();
 
   public: // AbstractPieceTableChange API
     virtual int type() const;
     virtual QString description() const;
-    virtual bool merge( const AbstractPieceTableChange *other );
-    virtual KHE::Section apply( PieceTable *pieceTable ) const;
-    virtual KHE::Section revert( PieceTable *pieceTable ) const;
-    virtual KHE::ArrayChangeMetrics metrics() const;
+    virtual bool merge( const AbstractPieceTableChange* other );
+    virtual AddressRange apply( PieceTable* pieceTable ) const;
+    virtual AddressRange revert( PieceTable* pieceTable ) const;
+    virtual ArrayChangeMetrics metrics() const;
 
   protected:
-    KHE::Section mRemoveSection;
+    AddressRange mRemoveRange;
     PieceList mRemovedPieces;
 };
 
-inline RemovePieceTableChange::RemovePieceTableChange( const KHE::Section &removeSection, const PieceList &removedPieces )
- : mRemoveSection( removeSection ), mRemovedPieces( removedPieces ) {}
+
+inline RemovePieceTableChange::RemovePieceTableChange( const AddressRange& removeRange, const PieceList& removedPieces )
+  : mRemoveRange( removeRange ),
+    mRemovedPieces( removedPieces )
+{}
 }
 
 #endif
