@@ -30,18 +30,18 @@
 #include "bytearraytablelayout.h"
 
 
-namespace KHEUI
+namespace Okteta
 {
 
 AbstractByteArrayView::AbstractByteArrayView( AbstractByteArrayViewPrivate* dd, QWidget* parent )
- : ColumnsView( parent ),
+  : ColumnsView( parent ),
     d_ptr( dd )
 {
     Q_D( AbstractByteArrayView );
     d->init();
 }
 
-KHECore::AbstractByteArrayModel* AbstractByteArrayView::byteArrayModel() const
+Okteta::AbstractByteArrayModel* AbstractByteArrayView::byteArrayModel() const
 {
     Q_D( const AbstractByteArrayView );
     return d->byteArrayModel();
@@ -82,7 +82,7 @@ AbstractByteArrayView::ValueCoding AbstractByteArrayView::valueCoding() const
     Q_D( const AbstractByteArrayView );
     return d->valueCoding();
 }
-const KHECore::ValueCodec* AbstractByteArrayView::valueCodec() const
+const Okteta::ValueCodec* AbstractByteArrayView::valueCodec() const
 {
     Q_D( const AbstractByteArrayView );
     return d->valueCodec();
@@ -97,7 +97,7 @@ const QString& AbstractByteArrayView::charCodingName() const
     Q_D( const AbstractByteArrayView );
     return d->charCodingName();
 }
-const KHECore::CharCodec* AbstractByteArrayView::charCodec() const
+const Okteta::CharCodec* AbstractByteArrayView::charCodec() const
 {
     Q_D( const AbstractByteArrayView );
     return d->charCodec();
@@ -119,18 +119,18 @@ int AbstractByteArrayView::noOfBytesPerLine() const
     Q_D( const AbstractByteArrayView );
     return d->noOfBytesPerLine();
 }
-int AbstractByteArrayView::firstLineOffset()  const
+Address AbstractByteArrayView::firstLineOffset()  const
 {
     Q_D( const AbstractByteArrayView );
     return d->firstLineOffset();
 }
-int AbstractByteArrayView::startOffset() const
+Address AbstractByteArrayView::startOffset() const
 {
     Q_D( const AbstractByteArrayView );
     return d->startOffset();
 }
 
-int AbstractByteArrayView::cursorPosition() const
+Address AbstractByteArrayView::cursorPosition() const
 {
     Q_D( const AbstractByteArrayView );
     return d->cursorPosition();
@@ -140,13 +140,19 @@ bool AbstractByteArrayView::isCursorBehind() const
     Q_D( const AbstractByteArrayView );
     return d->isCursorBehind();
 }
-AbstractByteArrayView::ResizeStyle AbstractByteArrayView::resizeStyle() const
+AbstractByteArrayView::LayoutStyle AbstractByteArrayView::layoutStyle() const
 {
     Q_D( const AbstractByteArrayView );
-    return d->resizeStyle();
+    return d->layoutStyle();
 }
 
-KHE::Section AbstractByteArrayView::selection() const
+bool AbstractByteArrayView::offsetColumnVisible() const
+{
+    Q_D( const AbstractByteArrayView );
+    return d->offsetColumnVisible();
+}
+
+AddressRange AbstractByteArrayView::selection() const
 {
     Q_D( const AbstractByteArrayView );
     return d->selection();
@@ -168,6 +174,12 @@ QMimeData* AbstractByteArrayView::selectionAsMimeData() const
     return d->selectionAsMimeData();
 }
 
+AddressRange AbstractByteArrayView::marking() const
+{
+    Q_D( const AbstractByteArrayView );
+    return d->marking();
+}
+
 
 void AbstractByteArrayView::pasteData( const QMimeData* data )
 {
@@ -184,19 +196,19 @@ bool AbstractByteArrayView::canReadData( const QMimeData* data ) const
 void AbstractByteArrayView::cut()
 {
     Q_D( AbstractByteArrayView );
-    d->cut();
+    d->cutToClipboard();
 }
 
 void AbstractByteArrayView::copy()
 {
     Q_D( AbstractByteArrayView );
-    d->copy();
+    d->copyToClipboard();
 }
 
 void AbstractByteArrayView::paste()
 {
     Q_D( AbstractByteArrayView );
-    d->paste();
+    d->pasteFromClipboard();
 }
 
 void AbstractByteArrayView::insert( const QByteArray& data )
@@ -211,7 +223,7 @@ void AbstractByteArrayView::removeSelectedData()
     d->removeSelectedData();
 }
 
-void AbstractByteArrayView::setByteArrayModel( KHECore::AbstractByteArrayModel* byteArrayModel )
+void AbstractByteArrayView::setByteArrayModel( Okteta::AbstractByteArrayModel* byteArrayModel )
 {
     Q_D( AbstractByteArrayView );
     d->setByteArrayModel( byteArrayModel );
@@ -235,10 +247,10 @@ void AbstractByteArrayView::setOverwriteOnly( bool overwriteOnly )
     d->setOverwriteOnly( overwriteOnly );
 }
 
-void AbstractByteArrayView::setResizeStyle( ResizeStyle resizeStyle )
+void AbstractByteArrayView::setLayoutStyle( LayoutStyle layoutStyle )
 {
     Q_D( AbstractByteArrayView );
-    d->setResizeStyle( resizeStyle );
+    d->setLayoutStyle( layoutStyle );
 }
 
 void AbstractByteArrayView::setNoOfBytesPerLine( int noOfBytesPerLine )
@@ -248,13 +260,13 @@ void AbstractByteArrayView::setNoOfBytesPerLine( int noOfBytesPerLine )
 }
 
 
-void AbstractByteArrayView::setStartOffset( int startOffset )
+void AbstractByteArrayView::setStartOffset( Address startOffset )
 {
     Q_D( AbstractByteArrayView );
     d->setStartOffset( startOffset );
 }
 
-void AbstractByteArrayView::setFirstLineOffset( int firstLineOffset )
+void AbstractByteArrayView::setFirstLineOffset( Address firstLineOffset )
 {
     Q_D( AbstractByteArrayView );
     d->setFirstLineOffset( firstLineOffset );
@@ -266,7 +278,7 @@ void AbstractByteArrayView::setReadOnly( bool readOnly )
     d->setReadOnly( readOnly );
 }
 
-int AbstractByteArrayView::visibleCodings() const
+AbstractByteArrayView::CodingTypes AbstractByteArrayView::visibleCodings() const
 {
     Q_D( const AbstractByteArrayView );
     return d->visibleCodings();
@@ -299,6 +311,12 @@ void AbstractByteArrayView::setTabChangesFocus( bool tabChangesFocus )
     d->setTabChangesFocus( tabChangesFocus );
 }
 
+void AbstractByteArrayView::toggleOffsetColumn( bool showOffsetColumn )
+{
+    Q_D( AbstractByteArrayView );
+    d->toggleOffsetColumn( showOffsetColumn );
+}
+
 
 void AbstractByteArrayView::selectAll( bool select )
 {
@@ -306,28 +324,54 @@ void AbstractByteArrayView::selectAll( bool select )
     d->selectAll( select );
 }
 
-bool AbstractByteArrayView::selectWord( /*unsigned TODO:change all unneeded signed into unsigned!*/ int index )
+bool AbstractByteArrayView::selectWord( Address index )
 {
     Q_D( AbstractByteArrayView );
     return d->selectWord( index );
 }
 
-void AbstractByteArrayView::setCursorPosition( int index, bool isBehind )
+void AbstractByteArrayView::setCursorPosition( Address index, bool isBehind )
 {
     Q_D( AbstractByteArrayView );
     d->setCursorPosition( index, isBehind );
 }
 
-void AbstractByteArrayView::setSelectionCursorPosition( int index )
+void AbstractByteArrayView::setSelectionCursorPosition( Address index )
 {
     Q_D( AbstractByteArrayView );
     d->setSelectionCursorPosition( index );
 }
 
-void AbstractByteArrayView::setSelection( int start, int end )
+void AbstractByteArrayView::setSelection( Address start, Address end )
 {
     Q_D( AbstractByteArrayView );
-    d->setSelection( start, end );
+    d->setSelection( AddressRange(start,end) );
+}
+
+void AbstractByteArrayView::setSelection( const AddressRange& selection )
+{
+    Q_D( AbstractByteArrayView );
+    d->setSelection( selection );
+}
+
+
+void AbstractByteArrayView::setMarking( Address start, Address end )
+{
+    Q_D( AbstractByteArrayView );
+    d->setMarking( AddressRange(start,end) );
+}
+
+void AbstractByteArrayView::setMarking( const AddressRange& marking )
+{
+    Q_D( AbstractByteArrayView );
+    d->setMarking( marking );
+}
+
+
+void AbstractByteArrayView::ensureVisible( const AddressRange& range, bool ensureStartVisible )
+{
+    Q_D( AbstractByteArrayView );
+    d->ensureVisible( range, ensureStartVisible );
 }
 
 
@@ -337,7 +381,6 @@ void AbstractByteArrayView::ensureCursorVisible()
     d->ensureCursorVisible();
 }
 
-
 void AbstractByteArrayView::placeCursor( const QPoint& point )
 {
     Q_D( AbstractByteArrayView );
@@ -418,15 +461,24 @@ void AbstractByteArrayView::fontChange( const QFont& oldFont )
 
 QSize AbstractByteArrayView::sizeHint() const
 {
-    return QSize( columnsWidth(), columnsHeight() );
+    // TODO: calculate a sensible hint based on dynamic layout settings
+    return QSize( 400, 120 );// QSize( columnsWidth(), columnsHeight() );
 }
 
+Address AbstractByteArrayView::indexByPoint( const QPoint& point ) const
+{
+    Q_D( const AbstractByteArrayView );
+    return d->indexByPoint( point );
+}
+
+
 void AbstractByteArrayView::finishByteEdit()
 {
     Q_D( AbstractByteArrayView );
     d->finishByteEditor();
 }
 
+// TODO: remove me!
 void AbstractByteArrayView::emitSelectionSignals()
 {
     Q_D( AbstractByteArrayView );
@@ -434,7 +486,8 @@ void AbstractByteArrayView::emitSelectionSignals()
     const bool hasSelection = tableRanges()->hasSelection();
     if( !d->isOverwriteMode() ) emit cutAvailable( hasSelection );
     emit copyAvailable( hasSelection );
-    emit selectionChanged( hasSelection );
+    emit selectionChanged( selection() );
+    emit hasSelectedDataChanged( hasSelection );
 }
 
 void AbstractByteArrayView::updateChanged()
@@ -443,6 +496,18 @@ void AbstractByteArrayView::updateChanged()
     d->updateChanged();
 }
 
+void AbstractByteArrayView::copyToClipboard( QClipboard::Mode mode ) const
+{
+    Q_D( const AbstractByteArrayView );
+    d->copyToClipboard( mode );
+}
+
+void AbstractByteArrayView::pasteFromClipboard( QClipboard::Mode mode )
+{
+    Q_D( AbstractByteArrayView );
+    d->pasteFromClipboard( mode );
+}
+
 QRect AbstractByteArrayView::cursorRect() const
 {
     Q_D( const AbstractByteArrayView );
@@ -490,6 +555,34 @@ void AbstractByteArrayView::keyPressEvent( QKeyEvent* keyEvent )
         ColumnsView::keyPressEvent( keyEvent );
 }
 
+void AbstractByteArrayView::mousePressEvent( QMouseEvent* mouseEvent )
+{
+    Q_D( AbstractByteArrayView );
+    d->mousePressEvent( mouseEvent );
+}
+
+
+void AbstractByteArrayView::mouseMoveEvent( QMouseEvent* mouseEvent )
+{
+    Q_D( AbstractByteArrayView );
+    d->mouseMoveEvent( mouseEvent );
+}
+
+
+void AbstractByteArrayView::mouseReleaseEvent( QMouseEvent* mouseEvent )
+{
+    Q_D( AbstractByteArrayView );
+    d->mouseReleaseEvent( mouseEvent );
+}
+
+
+// gets called after press and release instead of a plain press event (?)
+void AbstractByteArrayView::mouseDoubleClickEvent( QMouseEvent* mouseEvent )
+{
+    Q_D( AbstractByteArrayView );
+    d->mouseDoubleClickEvent( mouseEvent );
+}
+
 void AbstractByteArrayView::wheelEvent( QWheelEvent* wheelEvent )
 {
     Q_D( AbstractByteArrayView );
