@@ -135,6 +135,12 @@ class ByteArrayJanusView : public QWidget
     void charCodecChanged( const QString& charCodingName );
     void focusChanged( bool hasFocus );
 
+  protected: // Q_SLOTS QWidget API
+    virtual void changeEvent( QEvent* event );
+
+  protected Q_SLOTS:
+    void setFontByGlobalSettings();
+
   private:
     AbstractByteArrayView* mView;
     int mViewModus;
