@@ -1121,7 +1121,7 @@ void Karamba::setSensor(const LineParser& lineParser, Meter* meter)
         SensorParams *sp = new SensorParams(meter);
         QString mntPt = lineParser.getString("MOUNTPOINT");
         if (mntPt.isEmpty()) {
-            mntPt = "/";
+            mntPt = '/';
         }
         // remove any trailing '/' from mount points in the .theme config, our
         // mntMap doesn't like trailing '/'s for matching in DiskSensor
@@ -1331,9 +1331,9 @@ void Karamba::setSensor(const LineParser& lineParser, Meter* meter)
             }
 
             QString propertiesLine = lineParser.getString("PROPERTIES");
-            const QStringList properties = propertiesLine.split(",");
+            const QStringList properties = propertiesLine.split(',');
             foreach (const QString &property, properties) {
-                QStringList options = property.split(":");
+                QStringList options = property.split(':');
                 if (options.count() == 2) {
                     plasmasensor->setProperty(options[0].toLatin1(), options[1]);
                 }
